/*
  ft.c (File Time)
  Print file's modification time.

   THIS SOFTWARE IS IN PUBLIC DOMAIN
     There is no limitation on any kind of usage of this code. If you
     modify this code please remove this header and rename the file.
     
     You use it because it is yours.
     
     Originally written and maintained by Matlib (matlib@matlibhax.com),
     any comments or suggestions are welcome.
     
   Change log:
    1  2007-04-09  Matlib 
    2  2009-02-21  + libarguments argument handling
                   + allow alternative date format
                   + allow multiple files
    3  2011-02-16  update to libarguments v. 3
*/


#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <sys/stat.h>
#include <time.h>

#include <arguments.h>


struct Argument arguments [] =
{
  {'f', "format", argument_string, ARGUMENT_F_PAR | ARGUMENT_F_ONCE, {.value_str = "%a, %d %b %Y %H:%M:%S %z\n"}},
  {}
};
#define ARG_FORM ((char *) (arguments [0].value))
#define ARG_F_FORM (arguments [0].flags)


int main (int const argc, char const *const *const argv)
{
  struct stat st;
  struct tm *tm;
  char buffer [1024];
  int n, p, files, errors;
  
  p = 0;
  files = 0;
  errors = 0;
loop:
  n = arguments_parse ("ft", "2 (2009-02-21)", "[[-f format] [path]]...", 
     "Print file's last modification time.", argc - p, argv + p, arguments);
  p += n;
  if (p == argc)
    return ((files == 1) && (errors != 0)) ? EXIT_FAILURE : EXIT_SUCCESS;
  files ++;
  if (stat (argv [p], &st) != 0)
  {
    fprintf (stderr, "ft: %s: stat: %s\n", argv [p], strerror (errno));
    errors ++;
  }
  else
  {
    tm = gmtime (&(st.st_mtime));
    if (strftime (buffer, sizeof (buffer), ARG_FORM, tm) != 0)
      printf (buffer);
  }
  arguments_clr_occurrence (arguments);
  goto loop;
}

